Matching Conditions - durian.match.able — durian v0.0.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- durian v0.0.1 documentation »
- Module API Reference »

# Matching Conditions - durian.match.able

class `durian.match.able.` `Any`(value)
  Matchable always matching anything.

class `durian.match.able.` `Contains`(value)

  Matchable checking if the matched string contains the matchee.

  Same as `other.find(value)`.

class `durian.match.able.` `Endswith`(value)

  Matchable checking if the matched string ends with the matchee.

  Same as `other.endswith(value)`.

class `durian.match.able.` `Is`(value)

  Matchable checking for strict equality.

  That is, the values must be identical. (same as the regular `==` operator.)

class `durian.match.able.` `Like`(value)
  Matchable checking if the matched string matches a regular expression.

class `durian.match.able.` `Matchable`(value)

  Base matchable class.

  Parameter: | value – See `value`.

  Matchables are used to modify the way a value is tested for equality.

  Subclasses of `Matchable` must implement the `__eq__()` method.

  `value`
    The value to match against.

class `durian.match.able.` `Startswith`(value)

  Matchable checking if the matched string starts with the matchee.

  Same as `other.startswith(value)`.

### Navigation

- index
- modules |
- next |
- previous |
- durian v0.0.1 documentation »
- Module API Reference »